/*******************************************************************************
********************************************************************************
**
**  Copyright(c) 2022, Alliance for Automotive Innovation
**  Used only under license from the Alliance for Automotive Innovation. All Rights Reserved.
**
**  Project:  J1699-3
**  FileName: VerifyControlSupportAndData.c
**  Author:   EnGenius
**  Date:     2/25/2022
**  Email:    <support@autosinnovate.org>
**
**  Purpose:  SAE J1699-3 Vehicle OBD II Compliance Test Cases Source Code.
**            This source code is intended to run the tests described in
**            the SAE J1699-3 document in an automated manner, when compiled
**            and used with an SAE J2534-compatible pass-thru device.
**
**            File j1699.c contains information on building and running this test.
**
**  Description:
**
**  Modifications:  12/07/2022  Initial Version
**
********************************************************************************
*******************************************************************************/

#include <stdio.h>    // C Library input and output declarations
#include <stdlib.h>   // C Library general function declarations
#include <time.h>     // C Library time and date declarations
#include <windows.h>  // Windows API declarations
#include "j2534.h"    // j1699 project j2534 declarations
#include "j1699.h"    // j1699 project general declarations


/*******************************************************************************
**
**  Function:  VerifyTIDSupportAndData -
**
**  Purpose:   Verify SID 8 control support and data
**
*******************************************************************************/
STATUS VerifyTIDSupportAndData ( void )
{
	STATUS        eRetCode;

	unsigned long InitialFailureCount;


	InitialFailureCount = GetFailureCount ( );

	// Request SID 8 support data
	eRetCode = RequestIDSupportData ( TIDREQUEST, TRUE );
	if ( eRetCode == FAIL )
	{
		return FAIL;
	}

	if ( eRetCode == ABORT )
	{
		return PASS;
	}

	// Try group support if ISO15765
	if ( gstProtocolList[gProtocolIdx].eProtocol == ISO15765 )
	{
		if ( RequestGroupIDSupportData ( TIDREQUEST ) == FAIL )
		{
			return FAIL;
		}
	}

	// Link active test to verify communication remained active for ALL protocols
	if ( VerifyECUCommunication ( ) != PASS )
	{
		return FAIL;
	}

	if ( InitialFailureCount != GetFailureCount ( ) )
	{
		// There could have been early/late responses that weren't treated as FAIL
		return FAIL;
	}
	else
	{
		return PASS;
	}

}
