/*******************************************************************************
********************************************************************************
**
**  Copyright(c) 2022, Alliance for Automotive Innovation
**  Used only under license from the Alliance for Automotive Innovation. All Rights Reserved.
**
**  Project:  J1699-3
**  FileName: VerifyReservedServices.c
**  Author:   EnGenius
**  Date:     2/25/2022
**  Email:    <support@autosinnovate.org>
**
**  Purpose:  SAE J1699-3 Vehicle OBD II Compliance Test Cases Source Code.
**            This source code is intended to run the tests described in
**            the SAE J1699-3 document in an automated manner, when compiled
**            and used with an SAE J2534-compatible pass-thru device.
**
**            File j1699.c contains information on building and running this test.
**
**  Description:
**
**  Modifications:  12/07/2022  Initial Version
**
********************************************************************************
*******************************************************************************/

#include <stdio.h>    // C Library input and output declarations
#include <stdlib.h>   // C Library general function declarations
#include <time.h>     // C Library time and date declarations
#include <windows.h>  // Windows API declarations
#include "j2534.h"    // j1699 project j2534 declarations
#include "j1699.h"    // j1699 project general declarations


/*******************************************************************************
**
**  Function:  VerifyReservedServices
**
**  Purpose:   Verify that all ECUs respond correctly to reserved/unused services
**
*******************************************************************************/
STATUS VerifyReservedServices ( void )
{
	REQ_MSG  stReqMsg;

	BOOL     bTestFailed = FALSE;
	BYTE     SidIdx;


	if ( gstProtocolList[gProtocolIdx].eProtocol != ISO15765 )
	{
		return PASS;
	}

	// For each SID
	for ( SidIdx = 0x00;
	      SidIdx <= 0x0F;
	      SidIdx++ )
	{
		switch ( SidIdx )
		{
			case 0x00:
			case 0x0B:
			case 0x0C:
			case 0x0D:
			case 0x0E:
			case 0x0F:
			{
				stReqMsg.SID    = SidIdx;
				stReqMsg.NumIds = 0;
				if ( RequestSid ( &stReqMsg, REQ_MSG_NORMAL|REQ_MSG_IGNORE_NO_RESPONSE ) != FAIL )
				{
					Log ( FAILURE, SCREENOUTPUTON, LOGOUTPUTON, NO_PROMPT,
					      "Sid $%02X response\n",
					      SidIdx );
					bTestFailed = TRUE;
				}
			}
			break;
		}
	}

	if ( VerifyECUCommunication ( ) != PASS )
	{
		bTestFailed = TRUE;
	}

	if ( bTestFailed == TRUE )
	{
		return FAIL;
	}

	return PASS;
}
